@@ -261,23 +261,24 @@ function fill_reshape(parent, dims::Integer...)
     fillsimilar(parent, dims...)
 end
 
-reshape(parent::AbstractFill, dims::Integer...) = reshape(parent, dims)
-reshape(parent::AbstractFill, dims::Union{Int,Colon}...) = reshape(parent, dims)
-reshape(parent::AbstractFill, dims::Union{Integer,Colon}...) = reshape(parent, dims)
-# resolve ambiguity with Base
-reshape(parent::AbstractFillVector, dims::Colon) = parent
-
-reshape(parent::AbstractFill, dims::Tuple{Vararg{Union{Integer,Colon}}}) =
-    fill_reshape(parent, Base._reshape_uncolon(parent, dims)...)
-reshape(parent::AbstractFill, dims::Tuple{Vararg{Union{Int,Colon}}}) =
-    fill_reshape(parent, Base._reshape_uncolon(parent, dims)...)
-reshape(parent::AbstractFill, shp::Tuple{Union{Integer,Base.OneTo}, Vararg{Union{Integer,Base.OneTo}}}) =
-    reshape(parent, Base.to_shape(shp))
+if VERSION < v"1.12.0-DEV.1726"
+    # resolve ambiguity with Base
+    reshape(parent::AbstractFillVector, ::Colon) = parent
+    reshape(parent::AbstractFill, dims::Integer...) = reshape(parent, dims)
+    reshape(parent::AbstractFill, dims::Union{Int,Colon}...) = reshape(parent, dims)
+    reshape(parent::AbstractFill, dims::Union{Integer,Colon}...) = reshape(parent, dims)
+    reshape(parent::AbstractFill, dims::Tuple{Vararg{Union{Integer,Colon}}}) =
+        fill_reshape(parent, Base._reshape_uncolon(parent, dims)...)
+    reshape(parent::AbstractFill, dims::Tuple{Vararg{Union{Int,Colon}}}) =
+        fill_reshape(parent, Base._reshape_uncolon(parent, dims)...)
+    reshape(parent::AbstractFill, shp::Tuple{Union{Integer,Base.OneTo}, Vararg{Union{Integer,Base.OneTo}}}) =
+        reshape(parent, Base.to_shape(shp))
+    # resolve ambiguity with Base
+    reshape(parent::AbstractFillVector, ::Tuple{Colon}) = parent
+end
 reshape(parent::AbstractFill, dims::Dims) = fill_reshape(parent, dims...)
 reshape(parent::AbstractFill, dims::Tuple{Integer, Vararg{Integer}}) = fill_reshape(parent, dims...)
 
-# resolve ambiguity with Base
-reshape(parent::AbstractFillVector, dims::Tuple{Colon}) = parent
 
 for (AbsTyp, Typ, funcs, func) in ((:AbstractZeros, :Zeros, :zeros, :zero), (:AbstractOnes, :Ones, :ones, :one))
     @eval begin
@@ -534,8 +535,9 @@ end
 # Also, maybe this should reuse the broadcasting behavior of the parent,
 # once AbstractFill types implement their own BroadcastStyle
 BroadcastStyle(::Type{<:RectDiagonal}) = LinearAlgebra.StructuredMatrixStyle{RectDiagonal}()
-LinearAlgebra.structured_broadcast_alloc(bc, ::Type{<:RectDiagonal}, ::Type{ElType}, n) where {ElType} =
-    RectDiagonal(Array{ElType}(undef, n), axes(bc))
+function LinearAlgebra.structured_broadcast_alloc(bc, ::Type{<:RectDiagonal}, ::Type{ElType}, n) where {ElType}
+    RectDiagonal(Array{ElType}(undef, minimum(n)), axes(bc))
+end
 @inline LinearAlgebra.fzero(S::RectDiagonal{T}) where {T} = zero(T)
 
 #########
